declare type Maybe<T> = T | null;
export declare type WebhookAttributes = WebhookCollectionsCreateAttributes | WebhookCollectionsUpdateAttributes | WebhookCollectionsDeleteAttributes;
interface WebhookAttributesBase {
    "X-Shopify-Topic": string;
    "X-Shopify-Webhook-Id": string;
    "X-Shopify-API-Version": string;
    "X-Shopify-Hmac-SHA256": string;
    "X-Shopify-Shop-Domain": string;
    "Content-Type": "application/json";
}
export interface WebhookCollectionsCreateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Collection-Id": string;
    "X-Shopify-Topic": "collections/create";
}
export interface WebhookCollectionsUpdateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Collection-Id": string;
    "X-Shopify-Topic": "collections/update";
}
export interface WebhookCollectionsDeleteAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Collection-Id": string;
    "X-Shopify-Topic": "collections/delete";
}
export interface WebhookProductsCreateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "products/create";
}
export interface WebhookProductsUpdateAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "products/update";
}
export interface WebhookProductsDeleteAttributes extends WebhookAttributesBase {
    /**
     * Integer ID, like "285352591544"
     */
    "X-Shopify-Product-Id": string;
    "X-Shopify-Topic": "products/delete";
}
export interface WebhookCollectionPayload {
    id: number;
    handle: string;
    title: string;
    updated_at: string;
    body_html: string;
    published_at: string;
    sort_order: string;
    template_suffix: string;
    disjunctive: boolean;
    rules: {
        column: string;
        relation: string;
        condition: string;
    }[];
    published_scope: string;
    admin_graphql_api_id: string;
}
export interface WebhookProductPayload {
    id: number;
    title: string;
    body_html: string;
    vendor: string;
    product_type: string;
    created_at: string;
    handle: string;
    updated_at: string;
    published_at: string;
    template_suffix: string;
    status: string;
    published_scope: string;
    tags: string;
    admin_graphql_api_id: string;
    variants: {
        id: number;
        product_id: number;
        title: string;
        price: string;
        sku: string;
        position: number;
        inventory_policy: string;
        compare_at_price: Maybe<string>;
        fulfillment_service: string;
        inventory_management: string;
        option1: Maybe<string>;
        option2: Maybe<string>;
        option3: Maybe<string>;
        created_at: string;
        updated_at: string;
        taxable: boolean;
        barcode: string;
        grams: number;
        image_id: Maybe<number>;
        weight: number;
        weight_unit: string;
        inventory_item_id: number;
        inventory_quantity: number;
        old_inventory_quantity: number;
        requires_shipping: boolean;
        admin_graphql_api_id: string;
    }[];
    options: {
        id: number;
        product_id: number;
        name: string;
        position: number;
        values: string[];
    }[];
    images: WebhookProductImagePayload[];
    image: Maybe<WebhookProductImagePayload>;
}
interface WebhookProductImagePayload {
    id: number;
    product_id: number;
    position: number;
    created_at: string;
    updated_at: string;
    alt: Maybe<string>;
    width: number;
    height: number;
    src: string;
    variant_ids: number[];
    admin_graphql_api_id: string;
}
export {};
